# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TransitRouterRouteEntryArgs', 'TransitRouterRouteEntry']

@pulumi.input_type
class TransitRouterRouteEntryArgs:
    def __init__(__self__, *,
                 destination_cidr_block: pulumi.Input[builtins.str],
                 transit_router_route_entry_next_hop_type: pulumi.Input[builtins.str],
                 transit_router_route_table_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TransitRouterRouteEntry resource.
        :param pulumi.Input[builtins.str] destination_cidr_block: 路由条目的目标网段。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_type: 路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 中转路由器实例关联的路由表的ID。
        :param pulumi.Input[builtins.str] description: TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] transit_router_route_entry_name: 路由条目的名称。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_id: 路由条目的下一跳ID。
        """
        pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        pulumi.set(__self__, "transit_router_route_entry_next_hop_type", transit_router_route_entry_next_hop_type)
        pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if transit_router_route_entry_name is not None:
            pulumi.set(__self__, "transit_router_route_entry_name", transit_router_route_entry_name)
        if transit_router_route_entry_next_hop_id is not None:
            pulumi.set(__self__, "transit_router_route_entry_next_hop_id", transit_router_route_entry_next_hop_id)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        路由条目的目标网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopType")
    def transit_router_route_entry_next_hop_type(self) -> pulumi.Input[builtins.str]:
        """
        路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_type")

    @transit_router_route_entry_next_hop_type.setter
    def transit_router_route_entry_next_hop_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_route_entry_next_hop_type", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> pulumi.Input[builtins.str]:
        """
        中转路由器实例关联的路由表的ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryName")
    def transit_router_route_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的名称。
        """
        return pulumi.get(self, "transit_router_route_entry_name")

    @transit_router_route_entry_name.setter
    def transit_router_route_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_name", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopId")
    def transit_router_route_entry_next_hop_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的下一跳ID。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_id")

    @transit_router_route_entry_next_hop_id.setter
    def transit_router_route_entry_next_hop_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_next_hop_id", value)


@pulumi.input_type
class _TransitRouterRouteEntryState:
    def __init__(__self__, *,
                 as_paths: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_type: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_type: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouterRouteEntry resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] as_paths: 路由条目的AS路径。
        :param pulumi.Input[builtins.str] created_time: 路由条目的创建时间。
        :param pulumi.Input[builtins.str] description: TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] destination_cidr_block: 路由条目的目标网段。
        :param pulumi.Input[builtins.str] status: 路由条目的状态。Available：可用。Creating：创建中。Pending：配置中。Deleting：删除中。Conflicted：未生效。
        :param pulumi.Input[builtins.str] transit_router_route_entry_id: TR路由条目的ID。
        :param pulumi.Input[builtins.str] transit_router_route_entry_name: 路由条目的名称。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_id: 路由条目的下一跳ID。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_type: 路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        :param pulumi.Input[builtins.str] transit_router_route_entry_type: 路由条目的类型。Static：静态路由。Propagated：自动学习路由。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 中转路由器实例关联的路由表的ID。
        :param pulumi.Input[builtins.str] updated_time: 路由条目的更新时间。
        """
        if as_paths is not None:
            pulumi.set(__self__, "as_paths", as_paths)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_cidr_block is not None:
            pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if transit_router_route_entry_id is not None:
            pulumi.set(__self__, "transit_router_route_entry_id", transit_router_route_entry_id)
        if transit_router_route_entry_name is not None:
            pulumi.set(__self__, "transit_router_route_entry_name", transit_router_route_entry_name)
        if transit_router_route_entry_next_hop_id is not None:
            pulumi.set(__self__, "transit_router_route_entry_next_hop_id", transit_router_route_entry_next_hop_id)
        if transit_router_route_entry_next_hop_type is not None:
            pulumi.set(__self__, "transit_router_route_entry_next_hop_type", transit_router_route_entry_next_hop_type)
        if transit_router_route_entry_type is not None:
            pulumi.set(__self__, "transit_router_route_entry_type", transit_router_route_entry_type)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="asPaths")
    def as_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        路由条目的AS路径。
        """
        return pulumi.get(self, "as_paths")

    @as_paths.setter
    def as_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "as_paths", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的目标网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的状态。Available：可用。Creating：创建中。Pending：配置中。Deleting：删除中。Conflicted：未生效。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryId")
    def transit_router_route_entry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由条目的ID。
        """
        return pulumi.get(self, "transit_router_route_entry_id")

    @transit_router_route_entry_id.setter
    def transit_router_route_entry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryName")
    def transit_router_route_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的名称。
        """
        return pulumi.get(self, "transit_router_route_entry_name")

    @transit_router_route_entry_name.setter
    def transit_router_route_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_name", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopId")
    def transit_router_route_entry_next_hop_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的下一跳ID。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_id")

    @transit_router_route_entry_next_hop_id.setter
    def transit_router_route_entry_next_hop_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_next_hop_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopType")
    def transit_router_route_entry_next_hop_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_type")

    @transit_router_route_entry_next_hop_type.setter
    def transit_router_route_entry_next_hop_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_next_hop_type", value)

    @property
    @pulumi.getter(name="transitRouterRouteEntryType")
    def transit_router_route_entry_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的类型。Static：静态路由。Propagated：自动学习路由。
        """
        return pulumi.get(self, "transit_router_route_entry_type")

    @transit_router_route_entry_type.setter
    def transit_router_route_entry_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_entry_type", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例关联的路由表的ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        路由条目的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:transitrouter/transitRouterRouteEntry:TransitRouterRouteEntry")
class TransitRouterRouteEntry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_type: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        通过为网络实例连接或跨地域连接关联的路由表创建或删除静态路由，能够灵活地控制中转路由器中的流量走向。

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteEntry:TransitRouterRouteEntry example "transit_router_route_table_id|transit_router_route_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] destination_cidr_block: 路由条目的目标网段。
        :param pulumi.Input[builtins.str] transit_router_route_entry_name: 路由条目的名称。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_id: 路由条目的下一跳ID。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_type: 路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 中转路由器实例关联的路由表的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterRouteEntryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        通过为网络实例连接或跨地域连接关联的路由表创建或删除静态路由，能够灵活地控制中转路由器中的流量走向。

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteEntry:TransitRouterRouteEntry example "transit_router_route_table_id|transit_router_route_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterRouteEntryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterRouteEntryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_entry_next_hop_type: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterRouteEntryArgs.__new__(TransitRouterRouteEntryArgs)

            __props__.__dict__["description"] = description
            if destination_cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'destination_cidr_block'")
            __props__.__dict__["destination_cidr_block"] = destination_cidr_block
            __props__.__dict__["transit_router_route_entry_name"] = transit_router_route_entry_name
            __props__.__dict__["transit_router_route_entry_next_hop_id"] = transit_router_route_entry_next_hop_id
            if transit_router_route_entry_next_hop_type is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_route_entry_next_hop_type'")
            __props__.__dict__["transit_router_route_entry_next_hop_type"] = transit_router_route_entry_next_hop_type
            if transit_router_route_table_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_route_table_id'")
            __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
            __props__.__dict__["as_paths"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_route_entry_id"] = None
            __props__.__dict__["transit_router_route_entry_type"] = None
            __props__.__dict__["updated_time"] = None
        super(TransitRouterRouteEntry, __self__).__init__(
            'bytepluscc:transitrouter/transitRouterRouteEntry:TransitRouterRouteEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            as_paths: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination_cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_entry_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_entry_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_entry_next_hop_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_entry_next_hop_type: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_entry_type: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouterRouteEntry':
        """
        Get an existing TransitRouterRouteEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] as_paths: 路由条目的AS路径。
        :param pulumi.Input[builtins.str] created_time: 路由条目的创建时间。
        :param pulumi.Input[builtins.str] description: TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] destination_cidr_block: 路由条目的目标网段。
        :param pulumi.Input[builtins.str] status: 路由条目的状态。Available：可用。Creating：创建中。Pending：配置中。Deleting：删除中。Conflicted：未生效。
        :param pulumi.Input[builtins.str] transit_router_route_entry_id: TR路由条目的ID。
        :param pulumi.Input[builtins.str] transit_router_route_entry_name: 路由条目的名称。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_id: 路由条目的下一跳ID。
        :param pulumi.Input[builtins.str] transit_router_route_entry_next_hop_type: 路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        :param pulumi.Input[builtins.str] transit_router_route_entry_type: 路由条目的类型。Static：静态路由。Propagated：自动学习路由。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 中转路由器实例关联的路由表的ID。
        :param pulumi.Input[builtins.str] updated_time: 路由条目的更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterRouteEntryState.__new__(_TransitRouterRouteEntryState)

        __props__.__dict__["as_paths"] = as_paths
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["destination_cidr_block"] = destination_cidr_block
        __props__.__dict__["status"] = status
        __props__.__dict__["transit_router_route_entry_id"] = transit_router_route_entry_id
        __props__.__dict__["transit_router_route_entry_name"] = transit_router_route_entry_name
        __props__.__dict__["transit_router_route_entry_next_hop_id"] = transit_router_route_entry_next_hop_id
        __props__.__dict__["transit_router_route_entry_next_hop_type"] = transit_router_route_entry_next_hop_type
        __props__.__dict__["transit_router_route_entry_type"] = transit_router_route_entry_type
        __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
        __props__.__dict__["updated_time"] = updated_time
        return TransitRouterRouteEntry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="asPaths")
    def as_paths(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        路由条目的AS路径。
        """
        return pulumi.get(self, "as_paths")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表路由条目的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的目标网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的状态。Available：可用。Creating：创建中。Pending：配置中。Deleting：删除中。Conflicted：未生效。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouterRouteEntryId")
    def transit_router_route_entry_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由条目的ID。
        """
        return pulumi.get(self, "transit_router_route_entry_id")

    @property
    @pulumi.getter(name="transitRouterRouteEntryName")
    def transit_router_route_entry_name(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的名称。
        """
        return pulumi.get(self, "transit_router_route_entry_name")

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopId")
    def transit_router_route_entry_next_hop_id(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的下一跳ID。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_id")

    @property
    @pulumi.getter(name="transitRouterRouteEntryNextHopType")
    def transit_router_route_entry_next_hop_type(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的下一跳类型。取值如下：Attachment：网络实例，表示匹配该路由条目的流量会被转发到指定的网络实例。BlackHole：黑洞，表示匹配该路由条目的流量会被丢弃。
        """
        return pulumi.get(self, "transit_router_route_entry_next_hop_type")

    @property
    @pulumi.getter(name="transitRouterRouteEntryType")
    def transit_router_route_entry_type(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的类型。Static：静态路由。Propagated：自动学习路由。
        """
        return pulumi.get(self, "transit_router_route_entry_type")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        中转路由器实例关联的路由表的ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        路由条目的更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpnGatewayResult',
    'AwaitableGetVpnGatewayResult',
    'get_vpn_gateway',
    'get_vpn_gateway_output',
]

@pulumi.output_type
class GetVpnGatewayResult:
    """
    A collection of values returned by getVpnGateway.
    """
    def __init__(__self__, asn=None, bandwidth=None, billing_type=None, business_status=None, connection_count=None, create_time=None, deleted_time=None, description=None, dual_tunnel_enabled=None, expired_time=None, id=None, ip_address=None, ip_stack_type=None, ip_version=None, ipsec_enabled=None, is_blocked=None, lock_reason=None, overdue_time=None, period=None, period_unit=None, project_name=None, route_count=None, secondary_ip_address=None, secondary_subnet_id=None, ssl_enabled=None, ssl_max_connections=None, status=None, subnet_id=None, tags=None, update_time=None, vpc_id=None, vpn_gateway_id=None, vpn_gateway_name=None):
        if asn and not isinstance(asn, int):
            raise TypeError("Expected argument 'asn' to be a int")
        pulumi.set(__self__, "asn", asn)
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if billing_type and not isinstance(billing_type, int):
            raise TypeError("Expected argument 'billing_type' to be a int")
        pulumi.set(__self__, "billing_type", billing_type)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if connection_count and not isinstance(connection_count, int):
            raise TypeError("Expected argument 'connection_count' to be a int")
        pulumi.set(__self__, "connection_count", connection_count)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dual_tunnel_enabled and not isinstance(dual_tunnel_enabled, bool):
            raise TypeError("Expected argument 'dual_tunnel_enabled' to be a bool")
        pulumi.set(__self__, "dual_tunnel_enabled", dual_tunnel_enabled)
        if expired_time and not isinstance(expired_time, str):
            raise TypeError("Expected argument 'expired_time' to be a str")
        pulumi.set(__self__, "expired_time", expired_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address and not isinstance(ip_address, str):
            raise TypeError("Expected argument 'ip_address' to be a str")
        pulumi.set(__self__, "ip_address", ip_address)
        if ip_stack_type and not isinstance(ip_stack_type, str):
            raise TypeError("Expected argument 'ip_stack_type' to be a str")
        pulumi.set(__self__, "ip_stack_type", ip_stack_type)
        if ip_version and not isinstance(ip_version, str):
            raise TypeError("Expected argument 'ip_version' to be a str")
        pulumi.set(__self__, "ip_version", ip_version)
        if ipsec_enabled and not isinstance(ipsec_enabled, bool):
            raise TypeError("Expected argument 'ipsec_enabled' to be a bool")
        pulumi.set(__self__, "ipsec_enabled", ipsec_enabled)
        if is_blocked and not isinstance(is_blocked, bool):
            raise TypeError("Expected argument 'is_blocked' to be a bool")
        pulumi.set(__self__, "is_blocked", is_blocked)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if period and not isinstance(period, int):
            raise TypeError("Expected argument 'period' to be a int")
        pulumi.set(__self__, "period", period)
        if period_unit and not isinstance(period_unit, str):
            raise TypeError("Expected argument 'period_unit' to be a str")
        pulumi.set(__self__, "period_unit", period_unit)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if route_count and not isinstance(route_count, int):
            raise TypeError("Expected argument 'route_count' to be a int")
        pulumi.set(__self__, "route_count", route_count)
        if secondary_ip_address and not isinstance(secondary_ip_address, str):
            raise TypeError("Expected argument 'secondary_ip_address' to be a str")
        pulumi.set(__self__, "secondary_ip_address", secondary_ip_address)
        if secondary_subnet_id and not isinstance(secondary_subnet_id, str):
            raise TypeError("Expected argument 'secondary_subnet_id' to be a str")
        pulumi.set(__self__, "secondary_subnet_id", secondary_subnet_id)
        if ssl_enabled and not isinstance(ssl_enabled, bool):
            raise TypeError("Expected argument 'ssl_enabled' to be a bool")
        pulumi.set(__self__, "ssl_enabled", ssl_enabled)
        if ssl_max_connections and not isinstance(ssl_max_connections, int):
            raise TypeError("Expected argument 'ssl_max_connections' to be a int")
        pulumi.set(__self__, "ssl_max_connections", ssl_max_connections)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpn_gateway_id and not isinstance(vpn_gateway_id, str):
            raise TypeError("Expected argument 'vpn_gateway_id' to be a str")
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)
        if vpn_gateway_name and not isinstance(vpn_gateway_name, str):
            raise TypeError("Expected argument 'vpn_gateway_name' to be a str")
        pulumi.set(__self__, "vpn_gateway_name", vpn_gateway_name)

    @property
    @pulumi.getter
    def asn(self) -> builtins.int:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.int:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> builtins.int:
        """
        VPN网关关联IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        创建VPN网关的时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        预期资源强制回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> builtins.bool:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> builtins.str:
        """
        VPN网关的到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> builtins.str:
        """
        VPN网关的公网IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> builtins.str:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> builtins.str:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> builtins.bool:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @property
    @pulumi.getter(name="isBlocked")
    def is_blocked(self) -> builtins.bool:
        """
        当前资源的状态是否被封禁。true：封禁false：未封禁。
        """
        return pulumi.get(self, "is_blocked")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> builtins.int:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> builtins.str:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeCount")
    def route_count(self) -> builtins.int:
        """
        VPN网关的路由条目数量。
        """
        return pulumi.get(self, "route_count")

    @property
    @pulumi.getter(name="secondaryIpAddress")
    def secondary_ip_address(self) -> builtins.str:
        """
        VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_ip_address")

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> builtins.str:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> builtins.bool:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> builtins.int:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetVpnGatewayTagResult']:
        """
        VPN网关已添加的全部标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        更新VPN网关的时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> builtins.str:
        """
        VPN网关的ID。
        """
        return pulumi.get(self, "vpn_gateway_id")

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> builtins.str:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")


class AwaitableGetVpnGatewayResult(GetVpnGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpnGatewayResult(
            asn=self.asn,
            bandwidth=self.bandwidth,
            billing_type=self.billing_type,
            business_status=self.business_status,
            connection_count=self.connection_count,
            create_time=self.create_time,
            deleted_time=self.deleted_time,
            description=self.description,
            dual_tunnel_enabled=self.dual_tunnel_enabled,
            expired_time=self.expired_time,
            id=self.id,
            ip_address=self.ip_address,
            ip_stack_type=self.ip_stack_type,
            ip_version=self.ip_version,
            ipsec_enabled=self.ipsec_enabled,
            is_blocked=self.is_blocked,
            lock_reason=self.lock_reason,
            overdue_time=self.overdue_time,
            period=self.period,
            period_unit=self.period_unit,
            project_name=self.project_name,
            route_count=self.route_count,
            secondary_ip_address=self.secondary_ip_address,
            secondary_subnet_id=self.secondary_subnet_id,
            ssl_enabled=self.ssl_enabled,
            ssl_max_connections=self.ssl_max_connections,
            status=self.status,
            subnet_id=self.subnet_id,
            tags=self.tags,
            update_time=self.update_time,
            vpc_id=self.vpc_id,
            vpn_gateway_id=self.vpn_gateway_id,
            vpn_gateway_name=self.vpn_gateway_name)


def get_vpn_gateway(id: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpnGatewayResult:
    """
    Data Source schema for Byteplus::VPN::VPNGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpn/getVpnGateway:getVpnGateway', __args__, opts=opts, typ=GetVpnGatewayResult).value

    return AwaitableGetVpnGatewayResult(
        asn=pulumi.get(__ret__, 'asn'),
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        business_status=pulumi.get(__ret__, 'business_status'),
        connection_count=pulumi.get(__ret__, 'connection_count'),
        create_time=pulumi.get(__ret__, 'create_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        dual_tunnel_enabled=pulumi.get(__ret__, 'dual_tunnel_enabled'),
        expired_time=pulumi.get(__ret__, 'expired_time'),
        id=pulumi.get(__ret__, 'id'),
        ip_address=pulumi.get(__ret__, 'ip_address'),
        ip_stack_type=pulumi.get(__ret__, 'ip_stack_type'),
        ip_version=pulumi.get(__ret__, 'ip_version'),
        ipsec_enabled=pulumi.get(__ret__, 'ipsec_enabled'),
        is_blocked=pulumi.get(__ret__, 'is_blocked'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        period=pulumi.get(__ret__, 'period'),
        period_unit=pulumi.get(__ret__, 'period_unit'),
        project_name=pulumi.get(__ret__, 'project_name'),
        route_count=pulumi.get(__ret__, 'route_count'),
        secondary_ip_address=pulumi.get(__ret__, 'secondary_ip_address'),
        secondary_subnet_id=pulumi.get(__ret__, 'secondary_subnet_id'),
        ssl_enabled=pulumi.get(__ret__, 'ssl_enabled'),
        ssl_max_connections=pulumi.get(__ret__, 'ssl_max_connections'),
        status=pulumi.get(__ret__, 'status'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        tags=pulumi.get(__ret__, 'tags'),
        update_time=pulumi.get(__ret__, 'update_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpn_gateway_id=pulumi.get(__ret__, 'vpn_gateway_id'),
        vpn_gateway_name=pulumi.get(__ret__, 'vpn_gateway_name'))
def get_vpn_gateway_output(id: Optional[pulumi.Input[builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpnGatewayResult]:
    """
    Data Source schema for Byteplus::VPN::VPNGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpn/getVpnGateway:getVpnGateway', __args__, opts=opts, typ=GetVpnGatewayResult)
    return __ret__.apply(lambda __response__: GetVpnGatewayResult(
        asn=pulumi.get(__response__, 'asn'),
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        business_status=pulumi.get(__response__, 'business_status'),
        connection_count=pulumi.get(__response__, 'connection_count'),
        create_time=pulumi.get(__response__, 'create_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        dual_tunnel_enabled=pulumi.get(__response__, 'dual_tunnel_enabled'),
        expired_time=pulumi.get(__response__, 'expired_time'),
        id=pulumi.get(__response__, 'id'),
        ip_address=pulumi.get(__response__, 'ip_address'),
        ip_stack_type=pulumi.get(__response__, 'ip_stack_type'),
        ip_version=pulumi.get(__response__, 'ip_version'),
        ipsec_enabled=pulumi.get(__response__, 'ipsec_enabled'),
        is_blocked=pulumi.get(__response__, 'is_blocked'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        period=pulumi.get(__response__, 'period'),
        period_unit=pulumi.get(__response__, 'period_unit'),
        project_name=pulumi.get(__response__, 'project_name'),
        route_count=pulumi.get(__response__, 'route_count'),
        secondary_ip_address=pulumi.get(__response__, 'secondary_ip_address'),
        secondary_subnet_id=pulumi.get(__response__, 'secondary_subnet_id'),
        ssl_enabled=pulumi.get(__response__, 'ssl_enabled'),
        ssl_max_connections=pulumi.get(__response__, 'ssl_max_connections'),
        status=pulumi.get(__response__, 'status'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        tags=pulumi.get(__response__, 'tags'),
        update_time=pulumi.get(__response__, 'update_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpn_gateway_id=pulumi.get(__response__, 'vpn_gateway_id'),
        vpn_gateway_name=pulumi.get(__response__, 'vpn_gateway_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceArgs', 'Workspace']

@pulumi.input_type
class WorkspaceArgs:
    def __init__(__self__, *,
                 instance_type_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Workspace resource.
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        """
        pulumi.set(__self__, "instance_type_id", instance_type_id)
        pulumi.set(__self__, "name", name)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> pulumi.Input[builtins.str]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _WorkspaceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type: Optional[pulumi.Input['WorkspaceInstanceTypeArgs']] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_push_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_query_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 prometheus_write_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 quota: Optional[pulumi.Input['WorkspaceQuotaArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]] = None,
                 usage: Optional[pulumi.Input['WorkspaceUsageArgs']] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 workspace_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Workspace resources.
        :param pulumi.Input[builtins.str] create_time: 工作区创建时间，RFC3339 格式。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input['WorkspaceInstanceTypeArgs'] instance_type: 工作区规格详情。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 工作区预期欠费回收时间，RFC3339 格式。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] prometheus_push_intranet_endpoint: 工作区 Push Gateway URL 地址。
        :param pulumi.Input[builtins.str] prometheus_query_intranet_endpoint: 工作区 Query URL 地址。
        :param pulumi.Input[builtins.str] prometheus_write_intranet_endpoint: 工作区 RemoteWrite URL 地址。
        :param pulumi.Input['WorkspaceQuotaArgs'] quota: 工作区配额详情。
        :param pulumi.Input[builtins.str] status: 工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        :param pulumi.Input['WorkspaceUsageArgs'] usage: 工作区用量。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        :param pulumi.Input[builtins.str] workspace_id: 工作区Id。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delete_protection_enabled is not None:
            pulumi.set(__self__, "delete_protection_enabled", delete_protection_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if instance_type_id is not None:
            pulumi.set(__self__, "instance_type_id", instance_type_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if overdue_reclaim_time is not None:
            pulumi.set(__self__, "overdue_reclaim_time", overdue_reclaim_time)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if prometheus_push_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_push_intranet_endpoint", prometheus_push_intranet_endpoint)
        if prometheus_query_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_query_intranet_endpoint", prometheus_query_intranet_endpoint)
        if prometheus_write_intranet_endpoint is not None:
            pulumi.set(__self__, "prometheus_write_intranet_endpoint", prometheus_write_intranet_endpoint)
        if quota is not None:
            pulumi.set(__self__, "quota", quota)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if workspace_id is not None:
            pulumi.set(__self__, "workspace_id", workspace_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区创建时间，RFC3339 格式。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @delete_protection_enabled.setter
    def delete_protection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_protection_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input['WorkspaceInstanceTypeArgs']]:
        """
        工作区规格详情。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input['WorkspaceInstanceTypeArgs']]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @instance_type_id.setter
    def instance_type_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区预期欠费回收时间，RFC3339 格式。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @overdue_reclaim_time.setter
    def overdue_reclaim_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_reclaim_time", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="prometheusPushIntranetEndpoint")
    def prometheus_push_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 Push Gateway URL 地址。
        """
        return pulumi.get(self, "prometheus_push_intranet_endpoint")

    @prometheus_push_intranet_endpoint.setter
    def prometheus_push_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_push_intranet_endpoint", value)

    @property
    @pulumi.getter(name="prometheusQueryIntranetEndpoint")
    def prometheus_query_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 Query URL 地址。
        """
        return pulumi.get(self, "prometheus_query_intranet_endpoint")

    @prometheus_query_intranet_endpoint.setter
    def prometheus_query_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_query_intranet_endpoint", value)

    @property
    @pulumi.getter(name="prometheusWriteIntranetEndpoint")
    def prometheus_write_intranet_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 RemoteWrite URL 地址。
        """
        return pulumi.get(self, "prometheus_write_intranet_endpoint")

    @prometheus_write_intranet_endpoint.setter
    def prometheus_write_intranet_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "prometheus_write_intranet_endpoint", value)

    @property
    @pulumi.getter
    def quota(self) -> Optional[pulumi.Input['WorkspaceQuotaArgs']]:
        """
        工作区配额详情。
        """
        return pulumi.get(self, "quota")

    @quota.setter
    def quota(self, value: Optional[pulumi.Input['WorkspaceQuotaArgs']]):
        pulumi.set(self, "quota", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkspaceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input['WorkspaceUsageArgs']]:
        """
        工作区用量。
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input['WorkspaceUsageArgs']]):
        pulumi.set(self, "usage", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        工作区Id。
        """
        return pulumi.get(self, "workspace_id")

    @workspace_id.setter
    def workspace_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workspace_id", value)


@pulumi.type_token("bytepluscc:vmp/workspace:Workspace")
class Workspace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        工作区（Workspace）是 VMP 服务中采集数据和规则的抽象整合，为用户提供物理隔离或逻辑隔离的 Prometheus 能力。在 VMP 服务中可创建不同的工作区，不同工作区中的数据彼此隔离。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        workspace_demo = bytepluscc.vmp.Workspace("WorkspaceDemo",
            username="WorkspaceDemo",
            password="***********",
            name="WorkspaceDemo",
            description="WorkspaceDemo",
            delete_protection_enabled=False,
            instance_type_id="vmp.standard.xxx",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vmp/workspace:Workspace example "workspace_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        工作区（Workspace）是 VMP 服务中采集数据和规则的抽象整合，为用户提供物理隔离或逻辑隔离的 Prometheus 能力。在 VMP 服务中可创建不同的工作区，不同工作区中的数据彼此隔离。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        workspace_demo = bytepluscc.vmp.Workspace("WorkspaceDemo",
            username="WorkspaceDemo",
            password="***********",
            name="WorkspaceDemo",
            description="WorkspaceDemo",
            delete_protection_enabled=False,
            instance_type_id="vmp.standard.xxx",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vmp/workspace:Workspace example "workspace_id"
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceArgs.__new__(WorkspaceArgs)

            __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
            __props__.__dict__["description"] = description
            if instance_type_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_type_id'")
            __props__.__dict__["instance_type_id"] = instance_type_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["password"] = password
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["username"] = username
            __props__.__dict__["create_time"] = None
            __props__.__dict__["instance_type"] = None
            __props__.__dict__["overdue_reclaim_time"] = None
            __props__.__dict__["prometheus_push_intranet_endpoint"] = None
            __props__.__dict__["prometheus_query_intranet_endpoint"] = None
            __props__.__dict__["prometheus_write_intranet_endpoint"] = None
            __props__.__dict__["quota"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["usage"] = None
            __props__.__dict__["workspace_id"] = None
        super(Workspace, __self__).__init__(
            'bytepluscc:vmp/workspace:Workspace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            delete_protection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_type: Optional[pulumi.Input[Union['WorkspaceInstanceTypeArgs', 'WorkspaceInstanceTypeArgsDict']]] = None,
            instance_type_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            overdue_reclaim_time: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_push_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_query_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            prometheus_write_intranet_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            quota: Optional[pulumi.Input[Union['WorkspaceQuotaArgs', 'WorkspaceQuotaArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkspaceTagArgs', 'WorkspaceTagArgsDict']]]]] = None,
            usage: Optional[pulumi.Input[Union['WorkspaceUsageArgs', 'WorkspaceUsageArgsDict']]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None,
            workspace_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Workspace':
        """
        Get an existing Workspace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: 工作区创建时间，RFC3339 格式。
        :param pulumi.Input[builtins.bool] delete_protection_enabled: 是否开启工作区删除保护,true：开启，false：关闭。
        :param pulumi.Input[builtins.str] description: 工作区描述信息，字符串形式，长度限制为 0～200。
        :param pulumi.Input[Union['WorkspaceInstanceTypeArgs', 'WorkspaceInstanceTypeArgsDict']] instance_type: 工作区规格详情。
        :param pulumi.Input[builtins.str] instance_type_id: 工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        :param pulumi.Input[builtins.str] name: 工作区名称，字符串形式，长度限制为 1～100。
        :param pulumi.Input[builtins.str] overdue_reclaim_time: 工作区预期欠费回收时间，RFC3339 格式。
        :param pulumi.Input[builtins.str] password: 工作区 BasicAuth 密码。
        :param pulumi.Input[builtins.str] project_name: 项目名称。
        :param pulumi.Input[builtins.str] prometheus_push_intranet_endpoint: 工作区 Push Gateway URL 地址。
        :param pulumi.Input[builtins.str] prometheus_query_intranet_endpoint: 工作区 Query URL 地址。
        :param pulumi.Input[builtins.str] prometheus_write_intranet_endpoint: 工作区 RemoteWrite URL 地址。
        :param pulumi.Input[Union['WorkspaceQuotaArgs', 'WorkspaceQuotaArgsDict']] quota: 工作区配额详情。
        :param pulumi.Input[builtins.str] status: 工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        :param pulumi.Input[Union['WorkspaceUsageArgs', 'WorkspaceUsageArgsDict']] usage: 工作区用量。
        :param pulumi.Input[builtins.str] username: 工作区 BasicAuth 用户名。
        :param pulumi.Input[builtins.str] workspace_id: 工作区Id。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceState.__new__(_WorkspaceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delete_protection_enabled"] = delete_protection_enabled
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["instance_type_id"] = instance_type_id
        __props__.__dict__["name"] = name
        __props__.__dict__["overdue_reclaim_time"] = overdue_reclaim_time
        __props__.__dict__["password"] = password
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["prometheus_push_intranet_endpoint"] = prometheus_push_intranet_endpoint
        __props__.__dict__["prometheus_query_intranet_endpoint"] = prometheus_query_intranet_endpoint
        __props__.__dict__["prometheus_write_intranet_endpoint"] = prometheus_write_intranet_endpoint
        __props__.__dict__["quota"] = quota
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["usage"] = usage
        __props__.__dict__["username"] = username
        __props__.__dict__["workspace_id"] = workspace_id
        return Workspace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        工作区创建时间，RFC3339 格式。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deleteProtectionEnabled")
    def delete_protection_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启工作区删除保护,true：开启，false：关闭。
        """
        return pulumi.get(self, "delete_protection_enabled")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        工作区描述信息，字符串形式，长度限制为 0～200。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output['outputs.WorkspaceInstanceType']:
        """
        工作区规格详情。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> pulumi.Output[builtins.str]:
        """
        工作区规格,vmp.standard.15d：15 天存储时长工作区。vmp.standard.30d：30 天存储时长工作区。vmp.standard.90d：90 天存储时长工作区。vmp.standard.180d：180 天存储时长工作区。vmp.standard.1y：1 年存储时长工作区。
        """
        return pulumi.get(self, "instance_type_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        工作区名称，字符串形式，长度限制为 1～100。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="overdueReclaimTime")
    def overdue_reclaim_time(self) -> pulumi.Output[builtins.str]:
        """
        工作区预期欠费回收时间，RFC3339 格式。
        """
        return pulumi.get(self, "overdue_reclaim_time")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        工作区 BasicAuth 密码。
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="prometheusPushIntranetEndpoint")
    def prometheus_push_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 Push Gateway URL 地址。
        """
        return pulumi.get(self, "prometheus_push_intranet_endpoint")

    @property
    @pulumi.getter(name="prometheusQueryIntranetEndpoint")
    def prometheus_query_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 Query URL 地址。
        """
        return pulumi.get(self, "prometheus_query_intranet_endpoint")

    @property
    @pulumi.getter(name="prometheusWriteIntranetEndpoint")
    def prometheus_write_intranet_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        工作区 RemoteWrite URL 地址。
        """
        return pulumi.get(self, "prometheus_write_intranet_endpoint")

    @property
    @pulumi.getter
    def quota(self) -> pulumi.Output['outputs.WorkspaceQuota']:
        """
        工作区配额详情。
        """
        return pulumi.get(self, "quota")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        工作区状态，取值：Creating：创建中 Active：正常 Updating：更新中 Deleting：删除中 OverdueShutted：欠费关停 Resuming：恢复中 Error：错误。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.WorkspaceTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def usage(self) -> pulumi.Output['outputs.WorkspaceUsage']:
        """
        工作区用量。
        """
        return pulumi.get(self, "usage")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        工作区 BasicAuth 用户名。
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="workspaceId")
    def workspace_id(self) -> pulumi.Output[builtins.str]:
        """
        工作区Id。
        """
        return pulumi.get(self, "workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerGroupArgs', 'ServerGroup']

@pulumi.input_type
class ServerGroupArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input['ServerGroupHealthCheckArgs']] = None,
                 ip_address_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sticky_session_config: Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]] = None):
        """
        The set of arguments for constructing a ServerGroup resource.
        :param pulumi.Input[builtins.str] vpc_id: 后端服务器组所属 Vpc 的 ID。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。
        :param pulumi.Input['ServerGroupHealthCheckArgs'] health_check: 服务器组健康检查配置信息。
        :param pulumi.Input[builtins.str] ip_address_type: 服务器组的IP地址类型。目前只支持 IPv4
        :param pulumi.Input[builtins.str] project_name: 后端服务器组所属项目名称。
        :param pulumi.Input[builtins.str] protocol: 后端协议：HTTP，HTTPS。
        :param pulumi.Input[builtins.str] scheduler: 调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。
        :param pulumi.Input[builtins.str] server_group_type: 后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        :param pulumi.Input[builtins.str] status: 服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input['ServerGroupStickySessionConfigArgs'] sticky_session_config: 会话保持功能的参数信息。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check is not None:
            pulumi.set(__self__, "health_check", health_check)
        if ip_address_type is not None:
            pulumi.set(__self__, "ip_address_type", ip_address_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if server_group_type is not None:
            pulumi.set(__self__, "server_group_type", server_group_type)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sticky_session_config is not None:
            pulumi.set(__self__, "sticky_session_config", sticky_session_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        后端服务器组所属 Vpc 的 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> Optional[pulumi.Input['ServerGroupHealthCheckArgs']]:
        """
        服务器组健康检查配置信息。
        """
        return pulumi.get(self, "health_check")

    @health_check.setter
    def health_check(self, value: Optional[pulumi.Input['ServerGroupHealthCheckArgs']]):
        pulumi.set(self, "health_check", value)

    @property
    @pulumi.getter(name="ipAddressType")
    def ip_address_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的IP地址类型。目前只支持 IPv4
        """
        return pulumi.get(self, "ip_address_type")

    @ip_address_type.setter
    def ip_address_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端协议：HTTP，HTTPS。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的名称。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        """
        return pulumi.get(self, "server_group_type")

    @server_group_type.setter
    def server_group_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_type", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="stickySessionConfig")
    def sticky_session_config(self) -> Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']]:
        """
        会话保持功能的参数信息。
        """
        return pulumi.get(self, "sticky_session_config")

    @sticky_session_config.setter
    def sticky_session_config(self, value: Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']]):
        pulumi.set(self, "sticky_session_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ServerGroupState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input['ServerGroupHealthCheckArgs']] = None,
                 ip_address_type: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_count: Optional[pulumi.Input[builtins.int]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sticky_session_config: Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerGroup resources.
        :param pulumi.Input[builtins.str] create_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。
        :param pulumi.Input['ServerGroupHealthCheckArgs'] health_check: 服务器组健康检查配置信息。
        :param pulumi.Input[builtins.str] ip_address_type: 服务器组的IP地址类型。目前只支持 IPv4
        :param pulumi.Input[builtins.str] project_name: 后端服务器组所属项目名称。
        :param pulumi.Input[builtins.str] protocol: 后端协议：HTTP，HTTPS。
        :param pulumi.Input[builtins.str] scheduler: 调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        :param pulumi.Input[builtins.int] server_count: 服务器组内后端服务器的个数。
        :param pulumi.Input[builtins.str] server_group_id: 后端服务器组的ID。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。
        :param pulumi.Input[builtins.str] server_group_type: 后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        :param pulumi.Input[builtins.str] status: 服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input['ServerGroupStickySessionConfigArgs'] sticky_session_config: 会话保持功能的参数信息。
        :param pulumi.Input[builtins.str] update_time: 后端服务器组的最近操作时间。
        :param pulumi.Input[builtins.str] vpc_id: 后端服务器组所属 Vpc 的 ID。
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check is not None:
            pulumi.set(__self__, "health_check", health_check)
        if ip_address_type is not None:
            pulumi.set(__self__, "ip_address_type", ip_address_type)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if scheduler is not None:
            pulumi.set(__self__, "scheduler", scheduler)
        if server_count is not None:
            pulumi.set(__self__, "server_count", server_count)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if server_group_type is not None:
            pulumi.set(__self__, "server_group_type", server_group_type)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sticky_session_config is not None:
            pulumi.set(__self__, "sticky_session_config", sticky_session_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> Optional[pulumi.Input['ServerGroupHealthCheckArgs']]:
        """
        服务器组健康检查配置信息。
        """
        return pulumi.get(self, "health_check")

    @health_check.setter
    def health_check(self, value: Optional[pulumi.Input['ServerGroupHealthCheckArgs']]):
        pulumi.set(self, "health_check", value)

    @property
    @pulumi.getter(name="ipAddressType")
    def ip_address_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组的IP地址类型。目前只支持 IPv4
        """
        return pulumi.get(self, "ip_address_type")

    @ip_address_type.setter
    def ip_address_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address_type", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]]:
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端协议：HTTP，HTTPS。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def scheduler(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        """
        return pulumi.get(self, "scheduler")

    @scheduler.setter
    def scheduler(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheduler", value)

    @property
    @pulumi.getter(name="serverCount")
    def server_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        服务器组内后端服务器的个数。
        """
        return pulumi.get(self, "server_count")

    @server_count.setter
    def server_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "server_count", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的名称。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        """
        return pulumi.get(self, "server_group_type")

    @server_group_type.setter
    def server_group_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_type", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="stickySessionConfig")
    def sticky_session_config(self) -> Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']]:
        """
        会话保持功能的参数信息。
        """
        return pulumi.get(self, "sticky_session_config")

    @sticky_session_config.setter
    def sticky_session_config(self, value: Optional[pulumi.Input['ServerGroupStickySessionConfigArgs']]):
        pulumi.set(self, "sticky_session_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组所属 Vpc 的 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:alb/serverGroup:ServerGroup")
class ServerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input[Union['ServerGroupHealthCheckArgs', 'ServerGroupHealthCheckArgsDict']]] = None,
                 ip_address_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sticky_session_config: Optional[pulumi.Input[Union['ServerGroupStickySessionConfigArgs', 'ServerGroupStickySessionConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        服务器组是后端服务器的逻辑集合。ALB 实例按照您配置的转发规则确定客户端请求将被转发到的服务器组。然后，ALB 实例根据您配置的负载均衡策略，将请求分发给服务器组内的后端服务器。后端服务器接收并处理请求。

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/serverGroup:ServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。
        :param pulumi.Input[Union['ServerGroupHealthCheckArgs', 'ServerGroupHealthCheckArgsDict']] health_check: 服务器组健康检查配置信息。
        :param pulumi.Input[builtins.str] ip_address_type: 服务器组的IP地址类型。目前只支持 IPv4
        :param pulumi.Input[builtins.str] project_name: 后端服务器组所属项目名称。
        :param pulumi.Input[builtins.str] protocol: 后端协议：HTTP，HTTPS。
        :param pulumi.Input[builtins.str] scheduler: 调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。
        :param pulumi.Input[builtins.str] server_group_type: 后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        :param pulumi.Input[builtins.str] status: 服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input[Union['ServerGroupStickySessionConfigArgs', 'ServerGroupStickySessionConfigArgsDict']] sticky_session_config: 会话保持功能的参数信息。
        :param pulumi.Input[builtins.str] vpc_id: 后端服务器组所属 Vpc 的 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        服务器组是后端服务器的逻辑集合。ALB 实例按照您配置的转发规则确定客户端请求将被转发到的服务器组。然后，ALB 实例根据您配置的负载均衡策略，将请求分发给服务器组内的后端服务器。后端服务器接收并处理请求。

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/serverGroup:ServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param ServerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check: Optional[pulumi.Input[Union['ServerGroupHealthCheckArgs', 'ServerGroupHealthCheckArgsDict']]] = None,
                 ip_address_type: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 scheduler: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_type: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sticky_session_config: Optional[pulumi.Input[Union['ServerGroupStickySessionConfigArgs', 'ServerGroupStickySessionConfigArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerGroupArgs.__new__(ServerGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["health_check"] = health_check
            __props__.__dict__["ip_address_type"] = ip_address_type
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["scheduler"] = scheduler
            __props__.__dict__["server_group_name"] = server_group_name
            __props__.__dict__["server_group_type"] = server_group_type
            __props__.__dict__["servers"] = servers
            __props__.__dict__["status"] = status
            __props__.__dict__["sticky_session_config"] = sticky_session_config
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["server_count"] = None
            __props__.__dict__["server_group_id"] = None
            __props__.__dict__["update_time"] = None
        super(ServerGroup, __self__).__init__(
            'bytepluscc:alb/serverGroup:ServerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            health_check: Optional[pulumi.Input[Union['ServerGroupHealthCheckArgs', 'ServerGroupHealthCheckArgsDict']]] = None,
            ip_address_type: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupListenerArgs', 'ServerGroupListenerArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            scheduler: Optional[pulumi.Input[builtins.str]] = None,
            server_count: Optional[pulumi.Input[builtins.int]] = None,
            server_group_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_name: Optional[pulumi.Input[builtins.str]] = None,
            server_group_type: Optional[pulumi.Input[builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            sticky_session_config: Optional[pulumi.Input[Union['ServerGroupStickySessionConfigArgs', 'ServerGroupStickySessionConfigArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'ServerGroup':
        """
        Get an existing ServerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。
        :param pulumi.Input[Union['ServerGroupHealthCheckArgs', 'ServerGroupHealthCheckArgsDict']] health_check: 服务器组健康检查配置信息。
        :param pulumi.Input[builtins.str] ip_address_type: 服务器组的IP地址类型。目前只支持 IPv4
        :param pulumi.Input[builtins.str] project_name: 后端服务器组所属项目名称。
        :param pulumi.Input[builtins.str] protocol: 后端协议：HTTP，HTTPS。
        :param pulumi.Input[builtins.str] scheduler: 调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        :param pulumi.Input[builtins.int] server_count: 服务器组内后端服务器的个数。
        :param pulumi.Input[builtins.str] server_group_id: 后端服务器组的ID。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。
        :param pulumi.Input[builtins.str] server_group_type: 后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        :param pulumi.Input[builtins.str] status: 服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input[Union['ServerGroupStickySessionConfigArgs', 'ServerGroupStickySessionConfigArgsDict']] sticky_session_config: 会话保持功能的参数信息。
        :param pulumi.Input[builtins.str] update_time: 后端服务器组的最近操作时间。
        :param pulumi.Input[builtins.str] vpc_id: 后端服务器组所属 Vpc 的 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerGroupState.__new__(_ServerGroupState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["health_check"] = health_check
        __props__.__dict__["ip_address_type"] = ip_address_type
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["scheduler"] = scheduler
        __props__.__dict__["server_count"] = server_count
        __props__.__dict__["server_group_id"] = server_group_id
        __props__.__dict__["server_group_name"] = server_group_name
        __props__.__dict__["server_group_type"] = server_group_type
        __props__.__dict__["servers"] = servers
        __props__.__dict__["status"] = status
        __props__.__dict__["sticky_session_config"] = sticky_session_config
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["vpc_id"] = vpc_id
        return ServerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> pulumi.Output['outputs.ServerGroupHealthCheck']:
        """
        服务器组健康检查配置信息。
        """
        return pulumi.get(self, "health_check")

    @property
    @pulumi.getter(name="ipAddressType")
    def ip_address_type(self) -> pulumi.Output[builtins.str]:
        """
        服务器组的IP地址类型。目前只支持 IPv4
        """
        return pulumi.get(self, "ip_address_type")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence['outputs.ServerGroupListener']]:
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        后端协议：HTTP，HTTPS。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def scheduler(self) -> pulumi.Output[builtins.str]:
        """
        调度算法。取值：wrr：加权轮询。wlc：加权最小连接数。sh：源地址哈希。
        """
        return pulumi.get(self, "scheduler")

    @property
    @pulumi.getter(name="serverCount")
    def server_count(self) -> pulumi.Output[builtins.int]:
        """
        服务器组内后端服务器的个数。
        """
        return pulumi.get(self, "server_count")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的名称。
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的类型。instance：服务器类型，该类型服务器组支持添加 ecs、eni 实例作为后端服务器。ip：IP类型，该类型服务器组支持添加 IP 地址作为后端服务器。
        """
        return pulumi.get(self, "server_group_type")

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Sequence['outputs.ServerGroupServer']]:
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        服务器组状态。Creating：创建中。Active：运行中。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stickySessionConfig")
    def sticky_session_config(self) -> pulumi.Output['outputs.ServerGroupStickySessionConfig']:
        """
        会话保持功能的参数信息。
        """
        return pulumi.get(self, "sticky_session_config")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ServerGroupTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组所属 Vpc 的 ID。
        """
        return pulumi.get(self, "vpc_id")

